@@ -1,6 +1,7 @@
 import ckan.plugins as plugins
 import ckan.plugins.toolkit as toolkit
 from ckan.lib.plugins import DefaultTranslation
+from ckan import model
 
 def get_groups():
     groups = toolkit.get_action('group_list')(data_dict={ 'all_fields': True })
@@ -13,6 +14,15 @@ def get_latest_packages():
     })
     return resources
 
+def get_visualizations():
+    values = model.Session.query(model.ResourceView).filter_by(view_type='visualize').all()
+    response = list(map(lambda x: x.as_dict(), values))
+    response.reverse()
+    for i in response:
+        resource = toolkit.get_action('resource_show')(data_dict={'id': i['resource_id']})
+        i['resource'] = resource
+    return response[0:5]
+    
 
 class LapazPlugin(plugins.SingletonPlugin, DefaultTranslation):
     plugins.implements(plugins.IConfigurer)
@@ -33,4 +43,8 @@ class LapazPlugin(plugins.SingletonPlugin, DefaultTranslation):
         # Template helper function names should begin with the name of the
         # extension they belong to, to avoid clashing with functions from
         # other extensions.
-        return { 'demo_groups': get_groups, 'demo_latest_packages': get_latest_packages }
\ No newline at end of file
+        return { 
+            'demo_groups': get_groups, 
+            'demo_latest_packages': get_latest_packages, 
+            'demo_visualizations': get_visualizations 
+        }
\ No newline at end of file
